==> packageinstaller-pkglist-libre_0.1.7.tar.xz: packageinstaller-pkglist-libre/qt5-docs.pm <==
<?xml version="1.0"?>
<app>

<category>
Development
</category>

<name>
QT5 Documention
</name>

<description>
   <am>Documentation files for Qt-5 and QtCreator IDE</am>
   <ar>Documentation files for Qt-5 and QtCreator IDE</ar>
   <be>Documentation files for Qt-5 and QtCreator IDE</be>
   <bg>Documentation files for Qt-5 and QtCreator IDE</bg>
   <bn>Documentation files for Qt-5 and QtCreator IDE</bn>
   <ca>Fitxers de documentació per a l'IDE QT5 i QTCreator</ca>
   <cs>Documentation files for Qt-5 and QtCreator IDE</cs>
   <da>Dokumentationsfiler til Qt-5 og QtCreator IDE</da>
   <de>Dokumentationsdateien für Qt-5 und QtCreator IDE</de>
   <el>Αρχεία τεκμηρίωσης για IDE Qt-5 και QtCreator</el>
   <en>Documentation files for Qt-5 and QtCreator IDE</en>
   <es_ES>Archivos de documentación para Qt-5 y QtCreator IDE</es_ES>
   <es>Documentación de Qt-5 y del IDE QtCreator</es>
   <et>Documentation files for Qt-5 and QtCreator IDE</et>
   <eu>Documentation files for Qt-5 and QtCreator IDE</eu>
   <fa>Documentation files for Qt-5 and QtCreator IDE</fa>
   <fil_PH>Documentation files for Qt-5 and QtCreator IDE</fil_PH>
   <fi>Dokumentaatiotiedostot Qt-5 ja QtCreator ohjelmakehitysympäristölle</fi>
   <fr_BE>Fichiers de documentation pour Qt-5 et QtCreator IDE</fr_BE>
   <fr>Fichiers de documentation pour Qt-5 et QtCreator IDE</fr>
   <gl_ES>Documentation files for Qt-5 and QtCreator IDE</gl_ES>
   <he_IL>Documentation files for Qt-5 and QtCreator IDE</he_IL>
   <hi>Documentation files for Qt-5 and QtCreator IDE</hi>
   <hr>Documentation files for Qt-5 and QtCreator IDE</hr>
   <hu>Documentation files for Qt-5 and QtCreator IDE</hu>
   <id>Documentation files for Qt-5 and QtCreator IDE</id>
   <is>Documentation files for Qt-5 and QtCreator IDE</is>
   <it>File di documentazione per Qt-5 e QtCreator IDE</it>
   <ja>Qt-5 および QtCreator IDE のドキュメントファイル</ja>
   <kk>Documentation files for Qt-5 and QtCreator IDE</kk>
   <ko>Documentation files for Qt-5 and QtCreator IDE</ko>
   <lt>Documentation files for Qt-5 and QtCreator IDE</lt>
   <mk>Documentation files for Qt-5 and QtCreator IDE</mk>
   <mr>Documentation files for Qt-5 and QtCreator IDE</mr>
   <nb_NO>Documentation files for Qt-5 and QtCreator IDE</nb_NO>
   <nb>Dokumentasjonsfiler for Qt 5 og QtCreator IDE</nb>
   <nl_BE>Documentation files for Qt-5 and QtCreator IDE</nl_BE>
   <nl>Documentatiebestanden voor Qt-5 en QtCreator IDE</nl>
   <pl>pliki dokumentacji dla QT-5 i QtCreator IDE</pl>
   <pt_BR>Arquivos de documentação para Qt-5 e QtCreator IDE (Integrated Development Environment)</pt_BR>
   <pt>Documentation files for Qt-5 and QtCreator IDE</pt>
   <ro>Documentation files for Qt-5 and QtCreator IDE</ro>
   <ru>Документация по QT-5 и QtCreator IDE</ru>
   <sk>Documentation files for Qt-5 and QtCreator IDE</sk>
   <sl>Dokumentacija za Qt-5 in QtCreator IDE</sl>
   <sq>Documentation files for Qt-5 and QtCreator IDE</sq>
   <sr>Documentation files for Qt-5 and QtCreator IDE</sr>
   <sv>Dokumentationsfiler för Qt-5 och QtCreator IDE</sv>
   <th>Documentation files for Qt-5 and QtCreator IDE</th>
   <tr>QtCreator IDE ve Qt-5 için belgeleme dosyaları</tr>
   <uk>Documentation files for Qt-5 and QtCreator IDE</uk>
   <vi>Documentation files for Qt-5 and QtCreator IDE</vi>
   <zh_CN>Documentation files for Qt-5 and QtCreator IDE</zh_CN>
   <zh_HK>Documentation files for Qt-5 and QtCreator IDE</zh_HK>
   <zh_TW>Documentation files for Qt-5 and QtCreator IDE</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
qtcreator-doc
qt5-doc
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
qt5-doc
qtcreator-doc
</uninstall_package_names>
</app>

==> packageinstaller-pkglist-libre_0.2.1.tar.xz: packageinstaller-pkglist-libre/qt5-docs.pm <==
<?xml version="1.0"?>
<app>

<category>
Development
</category>

<name>
QT5 Documention
</name>

<description>
   <am>Documentation files for Qt-5 and QtCreator IDE</am>
   <ar>Documentation files for Qt-5 and QtCreator IDE</ar>
   <be>Documentation files for Qt-5 and QtCreator IDE</be>
   <bg>Documentation files for Qt-5 and QtCreator IDE</bg>
   <bn>Documentation files for Qt-5 and QtCreator IDE</bn>
   <ca>Fitxers de documentació per a l'IDE QT5 i QTCreator</ca>
   <cs>Documentation files for Qt-5 and QtCreator IDE</cs>
   <da>Dokumentationsfiler til Qt-5 og QtCreator IDE</da>
   <de>Dokumentationsdateien für Qt-5 und QtCreator IDE</de>
   <el>Αρχεία τεκμηρίωσης για IDE Qt-5 και QtCreator</el>
   <en>Documentation files for Qt-5 and QtCreator IDE</en>
   <es_ES>Archivos de documentación para Qt-5 y QtCreator IDE</es_ES>
   <es>Documentación de Qt-5 y del IDE QtCreator</es>
   <et>Documentation files for Qt-5 and QtCreator IDE</et>
   <eu>Documentation files for Qt-5 and QtCreator IDE</eu>
   <fa>Documentation files for Qt-5 and QtCreator IDE</fa>
   <fil_PH>Documentation files for Qt-5 and QtCreator IDE</fil_PH>
   <fi>Dokumentaatiotiedostot Qt-5 ja QtCreator ohjelmakehitysympäristölle</fi>
   <fr_BE>Fichiers de documentation pour Qt-5 et QtCreator IDE</fr_BE>
   <fr>Fichiers de documentation pour Qt-5 et QtCreator IDE</fr>
   <gl_ES>Documentation files for Qt-5 and QtCreator IDE</gl_ES>
   <gu>Documentation files for Qt-5 and QtCreator IDE</gu>
   <he_IL>Documentation files for Qt-5 and QtCreator IDE</he_IL>
   <hi>क्यूटी-5 व क्यूटी क्रिएटर आईडीई हेतु प्रलेखन फाइलें</hi>
   <hr>Documentation files for Qt-5 and QtCreator IDE</hr>
   <hu>Documentation files for Qt-5 and QtCreator IDE</hu>
   <id>Documentation files for Qt-5 and QtCreator IDE</id>
   <is>Documentation files for Qt-5 and QtCreator IDE</is>
   <it>File di documentazione per Qt-5 e QtCreator IDE</it>
   <ja>Qt-5 および QtCreator IDE のドキュメントファイル</ja>
   <kk>Documentation files for Qt-5 and QtCreator IDE</kk>
   <ko>Documentation files for Qt-5 and QtCreator IDE</ko>
   <lt>Documentation files for Qt-5 and QtCreator IDE</lt>
   <mk>Documentation files for Qt-5 and QtCreator IDE</mk>
   <mr>Documentation files for Qt-5 and QtCreator IDE</mr>
   <nb_NO>Documentation files for Qt-5 and QtCreator IDE</nb_NO>
   <nb>Dokumentasjonsfiler for Qt 5 og QtCreator IDE</nb>
   <nl_BE>Documentation files for Qt-5 and QtCreator IDE</nl_BE>
   <nl>Documentatiebestanden voor Qt-5 en QtCreator IDE</nl>
   <pl>pliki dokumentacji dla QT-5 i QtCreator IDE</pl>
   <pt_BR>Arquivos de documentação para Qt-5 e QtCreator IDE (Integrated Development Environment)</pt_BR>
   <pt>Ficheiros de documentação para Qt-5 e QtCreator IDE</pt>
   <ro>Documentation files for Qt-5 and QtCreator IDE</ro>
   <ru>Документация по QT-5 и QtCreator IDE</ru>
   <sk>Documentation files for Qt-5 and QtCreator IDE</sk>
   <sl>Dokumentacija za Qt-5 in QtCreator IDE</sl>
   <sq>Kartela dokumentimi për Qt-5 dhe QtCreator IDE</sq>
   <sr>Documentation files for Qt-5 and QtCreator IDE</sr>
   <sv>Dokumentationsfiler för Qt-5 och QtCreator IDE</sv>
   <th>Documentation files for Qt-5 and QtCreator IDE</th>
   <tr>QtCreator IDE ve Qt-5 için belgeleme dosyaları</tr>
   <uk>Documentation files for Qt-5 and QtCreator IDE</uk>
   <vi>Documentation files for Qt-5 and QtCreator IDE</vi>
   <zh_CN>Documentation files for Qt-5 and QtCreator IDE</zh_CN>
   <zh_HK>Documentation files for Qt-5 and QtCreator IDE</zh_HK>
   <zh_TW>Documentation files for Qt-5 and QtCreator IDE</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
qtcreator-doc
qt5-doc
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
qt5-doc
qtcreator-doc
</uninstall_package_names>
</app>
